#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

#
# Name: configureTSAMupgrade.sh
# 
# This file is directly called by the user during upgrade.
##################################################################

workDir=`dirname "$0"`
SCRIPT_NAME=$0

if [[ "$workDir" =~ ^/ ]]
then
	export TSAM_CONFIG_HOME=$workDir
else
	export TSAM_CONFIG_HOME="$(pwd)"/"${workDir}"
fi

. "$workDir/setupEnv.sh"

# Enable Localization
. "$workDir/../tools/i18n.sh" configureTSAM

# Set the Progress File
export PROGRESS_FILE=$TSAM_POSTINSTALL_PROGRESSUPGRADE

# Ask for WebSphere credentials
printLocalizedMessage QUESTION_WAS_USER
read WASADMIN
export WASADMIN=${WASADMIN:=wasadmin}

printLocalizedMessage QUESTION_WAS_PWD
stty -echo; read WASADMIN_PW; stty echo; echo
export WASADMIN_PW=${WASADMIN_PW:=invalid}

# Ask for WebSphere Port
printLocalizedMessage QUESTION_WAS_PORT
read MXServer_MAXIMO_PORT
export MXServer_MAXIMO_PORT=${MXServer_MAXIMO_PORT:=9443}


# The first parameter is the stepname, the second parameter is the scriptname without the ending .sh
function callStep
{
	CURRENT_STEP_ID=$1
	CURRENT_STEP=$2
	CURRENT_SCRIPTNAME=${CURRENT_STEP}.sh

	LOGFILE_NAME_PREFIX=${CURRENT_STEP_ID}_${CURRENT_STEP}_${TIMESTAMP}

	if ! test -f "$PROGRESS_FILE" || ! cat "$PROGRESS_FILE" | egrep "^$CURRENT_STEP_ID$" 1>/dev/null 2>/dev/null
	then
		# invoke the command
		"$workDir/${CURRENT_SCRIPTNAME}" 1>>${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log 2>>${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err
		RC=$?
		# write rc to stdout
		echo "RC="$RC >>${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log
		
		if ! [[ "$RC" == "0" ]]
		then
			printLocalizedMessage errorMessage
			echo ${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log
			echo ${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err
			echo
			printLocalizedMessage logTitle
			echo ${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log:
			tail -n 10 "${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log"
			echo ""
			echo ${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err:
			tail -n 10 "${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err"

			# write rc to stderr
			echo "RC="$RC >>${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err
		
			echo ""
			printLocalizedMessage fixAndRestart
			printLocalizedMessage pressEnterToContinue
			read

			exit $RC
		fi
		echo $CURRENT_STEP_ID >> "$PROGRESS_FILE"
	fi
}

function unittest
{
	if test -f "$workDir"/$(basename "$SCRIPT_NAME") && ! printLocalizedMessage a | grep "^[*][*][*]" 1>/dev/null 2>/dev/null
	then
		exit 0
	else
		exit 1
	fi
}

if [[ "$1" == "--test" ]]
then
	unittest
fi

printLocalizedMessage logDestination

mkdir -p $TSAM_LOG

if test -f "$PROGRESS_FILE"
then
	echo ""
	printLocalizedMessage warningNotClean_1
	echo ""
	printLocalizedMessage warningNotClean_2
	echo ""
	printLocalizedMessage warningNotClean_3
	echo ""
	printLocalizedMessage warningNotClean_4
	read KEY
	if [[ "$KEY" == "n" ]]
	then
		exit 4
	fi	
	if [[ "$KEY" == "y" ]]
	then
		printLocalizedMessage postInstallRestartLabel
		rm -f "$PROGRESS_FILE"
	fi	
	# otherwise continue with the next step as indicated by $PROGRESS_FILE
fi

echo ""

printLocalizedMessage middlewareCheckLabel
callStep U01_CHECK_MIDDLEWARE checkMiddleware

printLocalizedMessage stepTSAMcomponentsLabel
callStep U02_CHANGE_APPLICATION_CLASSLOADER changeApplClassLoaderOrderToPARENT
callStep U03_CHANGE_APPLICATION_WAR_CLASSLOADER changeApplWARClassLoaderPolicyToSINGLE
callStep U04_ENABLE_CLASSLOADER_RELOAD enableApplClassReloading

printLocalizedMessage stopWASLabel
callStep U05_STOP_RESTART_WAS stopWAS

printLocalizedMessage startTIOLabel
callStep U06_SSHKEY_START_TIO startTIO

printLocalizedMessage pressEnterToContinue
read
