#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

#
# Name: setupEnv.sh
#
# This script is called by any shellscript used during
# post installation.
# This script is not called directly by the user.
# It is not recommended to call this script directly!
#
# Loads the variables into the environment, so that they can
# be used by the different scripts. To call this script, you have to
# set the variable in the environment where you want to call 
# configureTSAM.sh or configureMaxProperties.sh. If variables are not set,
# default values are used.

workDir=`dirname "$0"`

function setVariableByTIO
{
	DESTINATION_VARIABLE=$1
	TIO_ENVIRONMENT_VARIABLE=$2
	WASRXUSER=$3
	
	VALUE=$(su - $WASRXUSER	-c ". \$TIO_HOME/tools/setupCmdLine.sh; env | grep $TIO_ENVIRONMENT_VARIABLE | cut -f 2 -d =")
	eval export $DESTINATION_VARIABLE=$VALUE
}

##############################################################################
#
# several static environment variables 
#
##############################################################################

export TIMESTAMP=`date +"%d%m%y%H%M%S"`

# Set by launchpad, disk1/install/postinstall
# export TSAM_CONFIG_HOME=

########################################################################## TPM
# Must be full qualified as in TPM defined. DO NOT USE LOCALHOST
if uname -s | grep -i AIX 1>/dev/null 2>/dev/null
then
	export TPM_PROV_SERVERNAME=${TPM_PROV_SERVERNAME:=`hostname`}
else
	export TPM_PROV_SERVERNAME=${TPM_PROV_SERVERNAME:=$(hostname -f)}
fi
export WASRXUSER=${WASRXUSER:=tioadmin}
export TIO_HOME=$(su - $WASRXUSER -c "echo \$TIO_HOME")

######################################################################### TSAM
export TSAM_HOME=/opt/IBM/tsam
export TSAM_POSTINSTALL_PROGRESS_1=$TSAM_HOME/.progressSetProperties
export TSAM_POSTINSTALL_PROGRESS_2=$TSAM_HOME/.progressPostInstall
export TSAM_POSTINSTALL_PROGRESSUPGRADE=$TSAM_HOME/.progressUpgrade
export TSAM_LOG=$TSAM_HOME/logs
export SSH_PASS_PHRASE=${SSH_PASS_PHRASE:=}
export SSH_USER_NAME=${SSH_USER_NAME:=root}
export SSH_PASSWORD=${SSH_PASSWORD:=}

########################################################################## DB2
export DB2_SERVER=${DB2_SERVER:=localhost}
export DB2_PORT=${DB2_PORT:=50005}
export DB2ADMIN=${DB2ADMIN:=ctginst1}
export DB2ADMIN_PW=${DB2ADMIN_PW:=}
export DB2MAXIMOUSER=${DB2MAXIMOUSER:=maximo}
export DB2MAXIMOPW=${DB2MAXIMOPW:=}
export DB2MAXIMODBNAME=${DB2MAXIMODBNAME:=maxdb71}
export DB2MAXIMOSCHEMANAME=${DB2MAXIMOSCHEMANAME:=maximo}

######################################################################### LDAP
export LDAP_SERVER=${LDAP_SERVER:=localhost}
export LDAP_PORT=${LDAP_PORT:=389}
export LDAP_ADMIN_FULL=${LDAP_ADMIN_FULL:=cn=root}
export LDAP_ADMIN_PW=${LDAP_ADMIN_PW:=}

########################################################################## WAS
setVariableByTIO WAS_HOME WAS_HOME $WASRXUSER
setVariableByTIO WAS_PROFILE_NAME APPSRV_PROFILE $WASRXUSER
export WAS_CELL_NAME=${WAS_CELL_NAME:=ctgCell01}
export WAS_CELLMANAGER_NAME=${WAS_CELLMANAGER_NAME:=ctgCellManager01}
export WAS_NODE_NAME=${WAS_NODE_NAME:=ctgNode01}
export WAS_MXSERVER_NAME=${WAS_MXSERVER_NAME:=MXServer}
export WAS_WEBSERVER_NAME=${WAS_WEBSERVER_NAME:=webserver1}
export MXServer_MAXIMO_PORT=${MXServer_MAXIMO_PORT:=9443}
export WASADMIN=${WASADMIN:=wasadmin}
export WASADMIN_PW=${WASADMIN_PW:=}

######################################################################### JAVA
export JAVA_HOME=${WAS_HOME}/java

##################################################### Helper scripts /commands
export WS_ADMIN_SCRIPT="$WAS_PROFILE_HOME/bin/wsadmin.sh"
export DROP_BACKUP_COMMAND="$SMP_HOME/maximo/tools/maximo/dropbackup.sh"

########################################################################## IHS
export IHS_HOME=${IHS_HOME:=/opt/IBM/HTTPServer}
export IHS_WEBSERVER1_DIR="$IHS_HOME/Plugins/config/webserver1"
export IHS_WEBSERVER1_PLUGIN_CFG_XML="$IHS_WEBSERVER1_DIR/plugin-cfg.xml"

#################################################################### BlueCloud
export FILE_CLOUD_PROPERTIES="/etc/cloud/cloud.properties"

########################################################################## ITM
export ITM_USER_ID=${ITM_USER_ID:=sysadmin}
export ITM_PASSWORD=${ITM_PASSWORD:=}

######################################################################## Paths
export WAS_PROFILE_HOME=$WAS_HOME/profiles/$WAS_PROFILE_NAME
export WS_ADMIN_SCRIPT=$WAS_PROFILE_HOME/bin/wsadmin.sh
export ANT_EXECUTABLE=$WAS_HOME/bin/ws_ant.sh
export MAXIMOEAR=${WAS_PROFILE_HOME}/installedApps/${WAS_CELL_NAME}/MAXIMO.ear

####################################################################### Maximo
export MAXADMIN=${MAXADMIN:=maxadmin}
export MAXADMIN_PW=${MAXADMIN_PW:=maxadmin}
export MAIL_SMTP_HOST=${MAIL_SMTP_HOST:=localhost}
export MXE_HOSTNAME=${MXE_HOSTNAME:=localhost}
export MXE_HOSTNAME_FULL=$MXE_HOSTNAME:$MXServer_MAXIMO_PORT
export MXE_ADMINEMAIL=${MXE_ADMINEMAIL:=root@localhost}
export MXE_INT_WEBAPPURL=https://$TPM_PROV_SERVERNAME:$MXServer_MAXIMO_PORT/meaweb/

################################################## Jython scripts to adapt WAS
export JDBC_PROVIDER_JYTHON="$TSAM_CONFIG_HOME/Jython/JDBCProvider.py"
export DATA_SOURCE_JYTHON="$TSAM_CONFIG_HOME/Jython/DataSource.py"
export WAS_GLOBAL_VARIABLE_JYTHON="$TSAM_CONFIG_HOME/Jython/WASGlobalVariable.py"
export TIMER_MANAGER_JYTHON="$TSAM_CONFIG_HOME/Jython/TimerManager.py"
export START_APPLICATION_JYTHON="$TSAM_CONFIG_HOME/Jython/startApplication.py"
export STOP_APPLICATION_JYTHON="$TSAM_CONFIG_HOME/Jython/stopApplication.py"
export DISABLE_AUTOSTART_FOR_APPLICATION_JYTHON="$TSAM_CONFIG_HOME/Jython/disableAutoStartForApplication.py"
export DISABLE_LDAP_CACHES_JYTHON="$TSAM_CONFIG_HOME/Jython/disableLDAPCaches.py"
export SYNC_NODE_JYTHON="$TSAM_CONFIG_HOME/Jython/syncNode.py"
export CHANGE_WAR_CL_POLICY_TO_SINGLE_JYTHON="$TSAM_CONFIG_HOME/Jython/changeApplWARClassLoaderPolicyToSINGLE.py"
export CHANGE_WAR_CL_ORDER_TO_PARENT_JYTHON="$TSAM_CONFIG_HOME/Jython/changeApplClassLoaderOrderToPARENT.py"
export ENABLE_APPL_CLASS_RELOADING_JYTHON="$TSAM_CONFIG_HOME/Jython/enableApplClassReloading.py"
export CONFIGURE_AUTH_FOR_CLOUDBURST_JYTHON="$TSAM_CONFIG_HOME/Jython/configureAuthForCloudEAR.py"
export GENERATE_IHS_PLUGIN_JYTHON="$TSAM_CONFIG_HOME/Jython/generateIHSPlugin.py"
export ESTABLISH_TRUST_RELATION_SHIP_JYTHON="$TSAM_CONFIG_HOME/Jython/establishTrustRelationshipForTSAM.py"

################################### Files used as input for dcmQueryCommand.sh
export INSERT_SCP_CLIENT_CREDENTIALS_DCM="$TSAM_CONFIG_HOME/DCM/insert_scpClientCredentials.dcm"
export INSERT_SCP_CLIENT_RSA_CREDENTIALS_DCM="$TSAM_CONFIG_HOME/DCM/insert_scpClientRSACredentials.dcm"
export INSERT_SSH_CLIENT_CREDENTIALS_DCM="$TSAM_CONFIG_HOME/DCM/insert_sshClientCredentials.dcm"
export INSERT_SSH_CLIENT_RSA_CREDENTIALS_DCM="$TSAM_CONFIG_HOME/DCM/insert_sshClientRSACredentials.dcm"
export INSERT_TIO_CREDENTIALS_DCM="$TSAM_CONFIG_HOME/DCM/insert_tioCredentials.dcm"
export UPDATE_SSH_CLIENT_MASTER_CREDENTIALS_DCM="$TSAM_CONFIG_HOME/DCM/update_sshClientMasterCredentials.dcm"
export UPDATE_SSH_SERVER_MASTER_CREDENTIALS_DCM="$TSAM_CONFIG_HOME/DCM/update_sshServerMasterCredentials.dcm"

export INSERT_SCP_CLIENT_CREDENTIALS_SH="$TSAM_CONFIG_HOME/insert_scpClientCredentials.sh"
export INSERT_SCP_CLIENT_RSA_CREDENTIALS_SH="$TSAM_CONFIG_HOME/insert_scpClientRSACredentials.sh"
export INSERT_SSH_CLIENT_CREDENTIALS_SH="$TSAM_CONFIG_HOME/insert_sshClientCredentials.sh"
export INSERT_SSH_CLIENT_RSA_CREDENTIALS_SH="$TSAM_CONFIG_HOME/insert_sshClientRSACredentials.sh"
export INSERT_TIO_CREDENTIALS_SH="$TSAM_CONFIG_HOME/insert_tioCredentials.sh"
export UPDATE_SSH_CLIENT_MASTER_CREDENTIALS_SH="$TSAM_CONFIG_HOME/update_sshClientMasterCredentials.sh"
export UPDATE_SSH_SERVER_MASTER_CREDENTIALS_SH="$TSAM_CONFIG_HOME/update_sshServerMasterCredentials.sh"

# Files used as input for xmlimport.sh
export INSERT_PROVISIONINGPROPERTIES_SH="$TSAM_CONFIG_HOME/xml/insert_ProvisioningProperties.xml"
